==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance.md <==
# AmazonEc2R5AdInstance


```text
aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance
```

```text
include('aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance')
```



| Illustration | AmazonEc2R5AdInstance | AmazonEc2R5AdInstanceCard | AmazonEc2R5AdInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance.png) | ![illustration for AmazonEc2R5AdInstance](../../../aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance.Local.png) | ![illustration for AmazonEc2R5AdInstanceCard](../../../aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstanceCard.Local.png) | ![illustration for AmazonEc2R5AdInstanceGroup](../../../aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstanceGroup.Local.png) |




## AmazonEc2R5AdInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2R5AdInstance
include('aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance')

' renders the element
AmazonEc2R5AdInstance('AmazonEc2R5AdInstance', 'Amazon Ec2 R5 Ad Instance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2R5AdInstance
include('aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance')

' renders the element
AmazonEc2R5AdInstance('AmazonEc2R5AdInstance', 'Amazon Ec2 R5 Ad Instance', 'an optional tech label')
@enduml
```

## AmazonEc2R5AdInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2R5AdInstanceCard
include('aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance')

' renders the element
AmazonEc2R5AdInstanceCard('AmazonEc2R5AdInstanceCard', 'Amazon Ec2 R5 Ad Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2R5AdInstanceCard
include('aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance')

' renders the element
AmazonEc2R5AdInstanceCard('AmazonEc2R5AdInstanceCard', 'Amazon Ec2 R5 Ad Instance Card', 'an optional description')
@enduml
```

## AmazonEc2R5AdInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2R5AdInstanceGroup
include('aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance')

' renders the element
AmazonEc2R5AdInstanceGroup('AmazonEc2R5AdInstanceGroup', 'Amazon Ec2 R5 Ad Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2R5AdInstanceGroup
include('aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance')

' renders the element
AmazonEc2R5AdInstanceGroup('AmazonEc2R5AdInstanceGroup', 'Amazon Ec2 R5 Ad Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance.md <==
# AmazonEc2R5AdInstance


```text
aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance
```

```text
include('aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance')
```



| Illustration | AmazonEc2R5AdInstance | AmazonEc2R5AdInstanceCard | AmazonEc2R5AdInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance.png) | ![illustration for AmazonEc2R5AdInstance](../../../aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance.Local.png) | ![illustration for AmazonEc2R5AdInstanceCard](../../../aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstanceCard.Local.png) | ![illustration for AmazonEc2R5AdInstanceGroup](../../../aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstanceGroup.Local.png) |




## AmazonEc2R5AdInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2R5AdInstance
include('aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance')

' renders the element
AmazonEc2R5AdInstance('AmazonEc2R5AdInstance', 'Amazon Ec2 R5 Ad Instance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2R5AdInstance
include('aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance')

' renders the element
AmazonEc2R5AdInstance('AmazonEc2R5AdInstance', 'Amazon Ec2 R5 Ad Instance', 'an optional tech label')
@enduml
```

## AmazonEc2R5AdInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2R5AdInstanceCard
include('aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance')

' renders the element
AmazonEc2R5AdInstanceCard('AmazonEc2R5AdInstanceCard', 'Amazon Ec2 R5 Ad Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2R5AdInstanceCard
include('aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance')

' renders the element
AmazonEc2R5AdInstanceCard('AmazonEc2R5AdInstanceCard', 'Amazon Ec2 R5 Ad Instance Card', 'an optional description')
@enduml
```

## AmazonEc2R5AdInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2R5AdInstanceGroup
include('aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance')

' renders the element
AmazonEc2R5AdInstanceGroup('AmazonEc2R5AdInstanceGroup', 'Amazon Ec2 R5 Ad Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2R5AdInstanceGroup
include('aws-q3-2021/Resource/Compute/AmazonEc2R5AdInstance')

' renders the element
AmazonEc2R5AdInstanceGroup('AmazonEc2R5AdInstanceGroup', 'Amazon Ec2 R5 Ad Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
